@@ -1,9 +1,9 @@
 package ColorTheme::Harmony::Analogous;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-08'; # DATE
+our $DATE = '2020-06-09'; # DATE
 our $DIST = 'ColorTheme-Harmony-Analogous'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use strict;
 use warnings;
@@ -80,7 +80,7 @@ sub new {
         $colors{"color" . ($i_central+$i)} = Color::RGB::Util::hsv2rgb(sprintf "%d %.4f %.4f", $central_h+$i*$h_distance, $s, $v);
     }
 
-    $self->{colors} = \%colors;
+    $self->{items} = \%colors;
     $self;
 }
 
@@ -99,7 +99,7 @@ ColorTheme::Harmony::Analogous - Create theme with colors equidistant in hue
 
 =head1 VERSION
 
-This document describes version 0.003 of ColorTheme::Harmony::Analogous (from Perl distribution ColorTheme-Harmony-Analogous), released on 2020-06-08.
+This document describes version 0.004 of ColorTheme::Harmony::Analogous (from Perl distribution ColorTheme-Harmony-Analogous), released on 2020-06-09.
 
 =head1 DESCRIPTION
 
